==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/briefcase/dialogs_ru.lua <==

dialogId("kuf-m-je", "font_small", "Oh no, not again...")
dialogStr("О нет, только не это опять...")

dialogId("kuf-v-noco", "font_big", "You know there’s nothing we can do about it.")
dialogStr("Ты ведь знаешь, мы ничего не можем с этим поделать.")

dialogId("kuf-v-hod", "font_big", "Let’s push it down so we can take a look at it.")
dialogStr("Давай столкнем его вниз, чтобы посмотреть, что внутри.")

dialogId("kuf-v-doprace", "font_big", "Well, let’s get to work.")
dialogStr("Что ж, за работу.")

dialogId("kuf-v-dotoho", "font_big", "So, now we can finally get started.")
dialogStr("Итак, мы можем начинать.")

dialogId("kuf-m-ven", "font_small", "Our first task is to get out of this room.")
dialogStr("Наша первая задача — выбраться из этой комнаты.")

dialogId("kuf-v-ukol", "font_big", "This, by the way, is going to be our task in all the other rooms as well.")
dialogStr("Впрочем, это будет нашей задачей на протяжении всей игры.")

dialogId("kuf-v-jeste", "font_big", "Should we watch it again?")
dialogStr("Может, стоит посмотреть это видео еще раз?")

dialogId("kuf-m-disk", "font_small", "How? The disk self-destructed.")
dialogStr("Как? Диск автоматически уничтожился.")

dialogId("kuf-v-restart", "font_big", "We could restart the level.")
dialogStr("Мы можем перезапустить уровень.")

dialogId("kuf-m-pravda", "font_small", "That’s true...")
dialogStr("Да, действительно.")

dialogId("kuf-m-dodilny", "font_small", "Come on, let’s take the player into the workshop and show him the work safety regulations.")
dialogStr("Ладно, пойдем покажем игроку нашу мастерскую и расскажем о правилах техники безопасности.")

dialogId("kuf-v-napad", "font_big", "Good idea.")
dialogStr("Это хорошая идея.")

dialogId("kuf-m-nezvednu", "font_small", "I can’t lift it. Can you give it a try?")
dialogStr("Я не могу поднять это. Можешь, ты попробуешь?")

dialogId("kuf-m-kousek", "font_small", "Just a little bit higher so I can swim underneath you.")
dialogStr("Тут достаточно места, чтобы я проплыла под тобой.")

dialogId("help1", "font_small", "For now, don’t touch anything, just watch and learn. We’ll show you what you should and shouldn’t do with us as well as what things we’re capable of.")
dialogStr("А теперь ничего не трогайте, а просто смотрите и запоминайте, что следует, а чего не следует делать.")

dialogId("help2", "font_big", "Before entering the workshop, let’s save the game - just press the F2 key.")
dialogStr("Давайте сохраним игру — просто нажмите клавишу F2.")

dialogId("help3", "font_small", "First we’ll show you what can hurt us.")
dialogStr("Сперва мы покажем, как можно сделать нам больно.")

dialogId("help4", "font_big", "I’ll volunteer to be the dummy.")
dialogStr("Выступаю добровольцем на роль подопытного.")

dialogId("help5", "font_small", "First of all, we shouldn’t drop things on each other.")
dialogStr("Прежде всего, нам не следует скидывать вещи друг на друга.")

dialogId("help6", "font_small", "We also can’t swim downwards when carrying an object, because it would fall on us.")
dialogStr("Также мы не можем плыть вниз, если держим какой-либо предмет, потому что он упадёт и раздавит нас.")

dialogId("help7", "font_big", "Now we’ll start again - or we can load the saved game by pressing the F3 key.")
dialogStr("Теперь нам остаётся либо начать сначала, либо загрузить игру с помощью клавиши F3.")

dialogId("help8", "font_big", "And now we’re back where we last saved the game.")
dialogStr("Теперь мы возвращаемся к моменту, на котором сохранили игру.")

dialogId("help9", "font_small", "Another thing we must not do is push objects along our back.")
dialogStr("Ещё одна вещь, которую нам не следует делать, — это толкать предмет, лежащий на спине товарища.")

dialogId("help10", "font_small", "Some objects are shaped in such a way that we could hold them and push them at the same time - but we’re not allowed to do this either.")
dialogStr("Некоторые предметы имеют форму, позволяющую одновременно поднимать и толкать их в сторону. Но так делать тоже не стоит.")

dialogId("help11", "font_big", "Again, we load a saved game by pressing the F3 key.")
dialogStr("Итак, мы снова можем загрузить сохранённую игру, нажав на клавишу F3.")

dialogId("help12", "font_small", "We also can’t drop additional objects on a pile that one of us is carrying.")
dialogStr("Также мы не можем скидывать предметы на другие предметы, если их держит товарищ.")

dialogId("help13", "font_small", "And unlike my bigger partner, I can’t move or even carry steel objects.")
dialogStr("И, в отличие от своего сильного друга, я не могу двигать и поднимать стальные предметы.")

dialogId("help14", "font_big", "We have loaded our saved game for the last time. Now we’ll show you all the things we’re capable of.")
dialogStr("Мы снова загрузили игру. Обещаем, это был последний раз. Теперь мы покажем вам, что мы умеем.")

dialogId("help15", "font_small", "We can always pick up objects and then let them fall.")
dialogStr("Мы всегда можем поднять предмет, а затем, выплыв из-под него, уронить.")

dialogId("help16", "font_small", "We can push an object along each other’s back only if the object will then be pushed onto another support...")
dialogStr("Мы можем двигать предметы, которые держим, только если в результате движения предмет окажется на опоре...")

dialogId("help17", "font_small", "... and even let it drop on each other in this case.")
dialogStr("...и даже скидывать их друг на друга в таком случае.")

dialogId("help18", "font_small", "I can even do this alone... I can swim down under it... or put it on this ledge.")
dialogStr("Я даже могу сделать это одна — заплыть под этот молоток и положить его на выступ.")

dialogId("help19", "font_small", "We can also push one object along the top of another object which we are supporting, but we can’t move the object that is directly on our back.")
dialogStr("Также мы можем подвинуть предмет, находящийся на другом, который, в свою очередь, держит напарник. Главное — не двигать предмет, лежащий непосредственно на спине товарища.")

dialogId("help20", "font_big", "We can also swim freely under an object which we are supporting and pass it to the other fish.")
dialogStr("С таким же успехом мы можем перемещаться под предметами, которые  держим, и передавать их напарнику.")

dialogId("help21", "font_small", "And we can push objects off of each other’s back, as long as the object falls down immediately.")
dialogStr("А также двигать предмет, который держит напарник, при условии, что он сразу же упадёт вниз.")

dialogId("help22", "font_big", "That’s about it for the rules. If you want to know more, press F1 and read the help section.")
dialogStr("Вот, вроде бы, и всё о правилах. Если что, нажмите F1 для вызова справки.")

dialogId("help23", "font_small", "In summary, we can only lift objects, let them drop, push them along a solid surface, push them onto a surface, and push them off of each other.")
dialogStr("Итак, мы можем поднимать предметы, скидывать их вниз, двигать по твёрдой поверхности, класть их на поверхность и сбрасывать друг с друга.")

==> fillets-ng-data_1.0.0.orig.tar.gz: fillets-ng-data-1.0.0/script/briefcase/dialogs_ru.lua <==

dialogId("kuf-m-je", "font_small", "Oh no, not again...")
dialogStr("О нет, только не это опять...")

dialogId("kuf-v-noco", "font_big", "You know there’s nothing we can do about it.")
dialogStr("Ты ведь знаешь, мы ничего не можем с этим поделать.")

dialogId("kuf-v-hod", "font_big", "Let’s push it down so we can take a look at it.")
dialogStr("Давай столкнем его вниз, чтобы посмотреть, что внутри.")

dialogId("kuf-v-doprace", "font_big", "Well, let’s get to work.")
dialogStr("Что ж, за работу.")

dialogId("kuf-v-dotoho", "font_big", "So, now we can finally get started.")
dialogStr("Итак, мы можем начинать.")

dialogId("kuf-m-ven", "font_small", "Our first task is to get out of this room.")
dialogStr("Наша первая задача — выбраться из этой комнаты.")

dialogId("kuf-v-ukol", "font_big", "This, by the way, is going to be our task in all the other rooms as well.")
dialogStr("Впрочем, это будет нашей задачей на протяжении всей игры.")

dialogId("kuf-v-jeste", "font_big", "Should we watch it again?")
dialogStr("Может, стоит посмотреть это видео еще раз?")

dialogId("kuf-m-disk", "font_small", "How? The disk self-destructed.")
dialogStr("Как? Диск автоматически уничтожился.")

dialogId("kuf-v-restart", "font_big", "We could restart the level.")
dialogStr("Мы можем перезапустить уровень.")

dialogId("kuf-m-pravda", "font_small", "That’s true...")
dialogStr("Да, действительно.")

dialogId("kuf-m-dodilny", "font_small", "Come on, let’s take the player into the workshop and show him the work safety regulations.")
dialogStr("Ладно, пойдем покажем игроку нашу мастерскую и расскажем о правилах техники безопасности.")

dialogId("kuf-v-napad", "font_big", "Good idea.")
dialogStr("Это хорошая идея.")

dialogId("kuf-m-nezvednu", "font_small", "I can’t lift it. Can you give it a try?")
dialogStr("Я не могу поднять это. Можешь, ты попробуешь?")

dialogId("kuf-m-kousek", "font_small", "Just a little bit higher so I can swim underneath you.")
dialogStr("Тут достаточно места, чтобы я проплыла под тобой.")

dialogId("help1", "font_small", "For now, don’t touch anything, just watch and learn. We’ll show you what you should and shouldn’t do with us as well as what things we’re capable of.")
dialogStr("А теперь ничего не трогайте, а просто смотрите и запоминайте, что следует, а чего не следует делать.")

dialogId("help2", "font_big", "Before entering the workshop, let’s save the game - just press the F2 key.")
dialogStr("Давайте сохраним игру — просто нажмите клавишу F2.")

dialogId("help3", "font_small", "First we’ll show you what can hurt us.")
dialogStr("Сперва мы покажем, как можно сделать нам больно.")

dialogId("help4", "font_big", "I’ll volunteer to be the dummy.")
dialogStr("Выступаю добровольцем на роль подопытного.")

dialogId("help5", "font_small", "First of all, we shouldn’t drop things on each other.")
dialogStr("Прежде всего, нам не следует скидывать вещи друг на друга.")

dialogId("help6", "font_small", "We also can’t swim downwards when carrying an object, because it would fall on us.")
dialogStr("Также мы не можем плыть вниз, если держим какой-либо предмет, потому что он упадёт и раздавит нас.")

dialogId("help7", "font_big", "Now we’ll start again - or we can load the saved game by pressing the F3 key.")
dialogStr("Теперь нам остаётся либо начать сначала, либо загрузить игру с помощью клавиши F3 (не нажимайте).")

dialogId("help8", "font_big", "And now we’re back where we last saved the game.")
dialogStr("Теперь мы возвращаемся к моменту, на котором сохранили игру.")

dialogId("help9", "font_small", "Another thing we must not do is push objects along our back.")
dialogStr("Ещё одна вещь, которую нам не следует делать, — это толкать предмет, лежащий на спине товарища.")

dialogId("help10", "font_small", "Some objects are shaped in such a way that we could hold them and push them at the same time - but we’re not allowed to do this either.")
dialogStr("Некоторые предметы имеют форму, позволяющую одновременно поднимать и толкать их в сторону. Но так делать тоже не стоит.")

dialogId("help11", "font_big", "Again, we load a saved game by pressing the F3 key.")
dialogStr("Итак, мы снова можем загрузить сохранённую игру, нажав на клавишу F3.")

dialogId("help12", "font_small", "We also can’t drop additional objects on a pile that one of us is carrying.")
dialogStr("Также мы не можем скидывать предметы на другие предметы, если их держит товарищ.")

dialogId("help13", "font_small", "And unlike my bigger partner, I can’t move or even carry steel objects.")
dialogStr("И, в отличие от своего сильного друга, я не могу двигать и поднимать стальные предметы.")

dialogId("help14", "font_big", "We have loaded our saved game for the last time. Now we’ll show you all the things we’re capable of.")
dialogStr("Мы снова загрузили игру. Обещаем, это был последний раз. Теперь мы покажем вам, что мы умеем.")

dialogId("help15", "font_small", "We can always pick up objects and then let them fall.")
dialogStr("Мы всегда можем поднять предмет, а затем, выплыв из-под него, уронить.")

dialogId("help16", "font_small", "We can push an object along each other’s back only if the object will then be pushed onto another support...")
dialogStr("Мы можем двигать предметы, которые держим, только если в результате движения предмет окажется на опоре...")

dialogId("help17", "font_small", "... and even let it drop on each other in this case.")
dialogStr("...и даже скидывать их друг на друга в таком случае.")

dialogId("help18", "font_small", "I can even do this alone... I can swim down under it... or put it on this ledge.")
dialogStr("Я даже могу сделать это одна — заплыть под этот молоток и положить его на выступ.")

dialogId("help19", "font_small", "We can also push one object along the top of another object which we are supporting, but we can’t move the object that is directly on our back.")
dialogStr("Также мы можем подвинуть предмет, находящийся на другом, который, в свою очередь, держит напарник. Главное — не двигать предмет, лежащий непосредственно на спине товарища.")

dialogId("help20", "font_big", "We can also swim freely under an object which we are supporting and pass it to the other fish.")
dialogStr("С таким же успехом мы можем перемещаться под предметами, которые  держим, и передавать их напарнику.")

dialogId("help21", "font_small", "And we can push objects off of each other’s back, as long as the object falls down immediately.")
dialogStr("А также двигать предмет, который держит напарник, при условии, что он сразу же упадёт вниз.")

dialogId("help22", "font_big", "That’s about it for the rules. If you want to know more, press F1 and read the help section.")
dialogStr("Вот, вроде бы, и всё о правилах. Если что, нажмите F1 для вызова справки.")

dialogId("help23", "font_small", "In summary, we can only lift objects, let them drop, push them along a solid surface, push them onto a surface, and push them off of each other.")
dialogStr("Итак, мы можем поднимать предметы, скидывать их вниз, двигать по твёрдой поверхности, класть их на поверхность и сбрасывать друг с друга.")
